@@ -1,7 +1,7 @@
 import inspect
 from functools import wraps
 from inspect import getattr_static
-from typing import Any, Callable, Dict, List, Type, TypeVar, cast
+from typing import Any, Callable, Dict, List, TypeVar, cast
 
 from cognite.tracing import span
 
@@ -29,7 +29,7 @@ def traced(f: T) -> T:
     return cast(T, decorated)
 
 
-def traced_methods(cls: Type) -> Type:
+def traced_methods(cls: T) -> T:
     """Decorator for enabling tracing of all public instance methods within the class"""
     for attr in cls.__dict__:
         attr_is_public_method = not attr.startswith("_") and callable(getattr(cls, attr))
